########## server
require(shiny)
require(OpenStreetMap)
require(maps)
#require(nnclust)
load("gifu_esri.Rdata")
load("jpn_merc.Rdata")
load("gifudata_k.Rdata")    # kanji version

par(family="serif")
map <- gifu_esri
colshift=7
selrow <- 1:125      #  short case  1:113
outside <- 128:131
outplace <- c("k","֓","C","֐")

shinyServer(function(input,output){
  
datasetInput <- reactive({
  switch(input$dataset,
         "Pepper"=colshift+1,
         "Corn"=colshift+2,
         "ThirdFinger"=colshift+3,
         "HairWhirl"=colshift+4,
         "Stilt"=colshift+5,
         "BeanBag"=colshift+6,
         "Uruchimai"=colshift+7,
         "Potato"=colshift+8,
         "Cotton"=colshift+9,
         "Taro"=colshift+10
  )
})

output$mapPlot <- renderPlot({
selcol <- datasetInput()
mdata <- cbind.data.frame(gifudata[selrow,1:3],word=gifudata[selrow,selcol])
mdata[,4] <- factor(mdata[,4])
legchr <- gifudata[outside, selcol]
legnum <- match(legchr, levels(mdata[,4]))
ccode <- as.integer(mdata[,4]) %% 26
inum <- input$num
icex <- input$icex
ilwd <- input$ilwd

# par(family="serif")

plot(map)
if (input$bdry) 
  plot(jpn_merc, add=TRUE, border=input$bcol,lwd=1.5)
if (inum<=0) { 
  sub <- mdata
  points(sub[,2],sub[,3], pch=ccode, col=ccode,
    cex=icex, lwd=ilwd)
} else {
  sub <- mdata[ccode==inum, ]
  points(sub[,2],sub[,3], pch=inum, col=inum,
    cex=icex, lwd=ilwd)
}

legend("topleft", paste(outplace, legchr),
       bg="lightyellow", col=legnum,lwd=-1,
       pch=legnum, pt.cex=icex, pt.lwd=ilwd, cex=1, text.font=1)

#ccode <- as.integer(mdata[,4])
tword <- table(mdata[,4])
nword <- lapply(tword, function(x) if (x<10) paste(" ",x,sep="") else as.character(x))
lword <-  paste(nword, names(nword))
lnum <- 1:length(lword)
pchshift <- 0

legend("bottomright", lword, bg="lightyellow", col=lnum,lwd=-1,
  pch=pchshift+lnum, pt.cex=max(1.2,input$rcex), pt.lwd=1.5, cex=input$rcex)

})

output$caption <- renderText({
#  par(family="serif")
  selcol <- datasetInput()
  mdata <- cbind.data.frame(gifudata[selrow,1:3],word=gifudata[selrow,selcol])
  mdata[,4] <- factor(mdata[,4])
  ccode <- as.integer(mdata[,4]) %% 26
  inum <- input$num
  paste(inum," (",
    sum(as.integer(mdata[,4])==inum, na.rm=TRUE),
	"/", nrow(mdata),
    ") ",
  ifelse(inum==0, paste(length(levels(mdata[,4])), "cases"),
         levels(mdata[,4])[inum]), 
  sep="")
})

})   
